DerivedField class

Defines a persisted value produced by a derived-field callback.

Inheritance
Annotations
  • @Target.new({TargetKind.method})

Constructors

DerivedField({String? name})
Creates a DerivedField by its attributes.
const

Properties

defaultValue → Object?
Optional default value for the field.
finalinherited
hashCode → int
The hash code for this object.
no setterinherited
name → String?
Name of the column in the underlying database.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited