Model class

Links a database table to a Dart class.

Annotations
  • @Target.new({TargetKind.classType})

Constructors

Model({String? name, List<IdSpec> primaryKey = const [GeneratedIdSpec()], Symbol? as})
Creates a Model by its attributes.
const

Properties

as Symbol?
Name for the Dart repository accessor of this model.
final
hashCode int
The hash code for this object.
no setterinherited
name String?
Name of the table in the underlying database.
final
primaryKey List<IdSpec>
Parts of the model's primary key.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited