GeneratedIdSpec class final
Describes a primary-key field generated by dORM.
The generated field is not required to exist in the annotated abstract class. as is its Dart property name, name is its storage name, and type is its Dart type.
Constructors
- GeneratedIdSpec({Symbol as = #id, String name = 'id', Type type = String})
-
Creates a generated primary-key specification.
const
Properties
- as → Symbol
-
Dart property name of the generated field.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
Storage name of the generated field.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- type → Type
-
Dart type of the generated field.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited